[Darshan-commits] [Darshan] branch, dev-modular, updated. darshan-2.3.1-174-g22bc23f

Service Account git at mcs.anl.gov
Thu Sep 10 10:52:26 CDT 2015


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "".

The branch, dev-modular has been updated
       via  22bc23f2782273ebe8c65eb559f67d9b4b8004e4 (commit)
      from  57cb76241543beb5fbbdd28b220940f068465a75 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 22bc23f2782273ebe8c65eb559f67d9b4b8004e4
Author: Shane Snyder <ssnyder at mcs.anl.gov>
Date:   Thu Sep 10 09:56:08 2015 -0500

    drop CP_ prefixes in runtime code

-----------------------------------------------------------------------

Summary of changes:
 darshan-runtime/configure                   |   30 ++++++++++----------
 darshan-runtime/configure.in                |   26 +++++++++---------
 darshan-runtime/darshan-core.h              |   17 +++++------
 darshan-runtime/darshan-mk-log-dirs.pl.in   |    2 +-
 darshan-runtime/darshan-runtime-config.h.in |   16 +++++-----
 darshan-runtime/doc/darshan-runtime.txt     |    2 +-
 darshan-runtime/lib/darshan-core.c          |   40 +++++++++++++-------------
 maint/config/check_zlib.m4                  |    4 +-
 8 files changed, 68 insertions(+), 69 deletions(-)


Diff of changes:
diff --git a/darshan-runtime/configure b/darshan-runtime/configure
index b7929bc..be3e002 100755
--- a/darshan-runtime/configure
+++ b/darshan-runtime/configure
@@ -625,7 +625,7 @@ DARSHAN_USE_BGQ
 MPICH_LIB_OLD
 DARSHAN_VERSION
 DISABLE_LDPRELOAD
-__CP_LOG_PATH
+__DARSHAN_LOG_PATH
 darshan_share_path
 darshan_lib_path
 PRI_MACROS_BROKEN
@@ -3467,8 +3467,8 @@ if test "${with_zlib+set}" = set; then :
     ZLIB_HOME="$withval"
     LDFLAGS="$LDFLAGS -L${ZLIB_HOME}/lib"
     CPPFLAGS="$CPPFLAGS -I${ZLIB_HOME}/include"
-    __CP_ZLIB_LINK_FLAGS="-L${ZLIB_HOME}/lib"
-    __CP_ZLIB_INCLUDE_FLAGS="-I${ZLIB_HOME}/include"
+    __DARSHAN_ZLIB_LINK_FLAGS="-L${ZLIB_HOME}/lib"
+    __DARSHAN_ZLIB_INCLUDE_FLAGS="-I${ZLIB_HOME}/include"
   else
     { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: Sorry, $withval does not exist, checking usual places" >&5
 $as_echo "$as_me: WARNING: Sorry, $withval does not exist, checking usual places" >&2;}
@@ -3561,7 +3561,7 @@ fi
 if test "${enable_group_readable_logs+set}" = set; then :
   enableval=$enable_group_readable_logs; if test "x$enableval" = "xyes" ; then
 
-$as_echo "#define __CP_GROUP_READABLE_LOGS 1" >>confdefs.h
+$as_echo "#define __DARSHAN_GROUP_READABLE_LOGS 1" >>confdefs.h
 
 fi
 
@@ -3576,7 +3576,7 @@ if test "${with_mem_align+set}" = set; then :
     else
 
 cat >>confdefs.h <<_ACEOF
-#define __CP_MEM_ALIGNMENT ${withval}
+#define __DARSHAN_MEM_ALIGNMENT ${withval}
 _ACEOF
 
         GOT_ALIGNMENT=1
@@ -3593,10 +3593,10 @@ if test "${with_log_path_by_env+set}" = set; then :
     else
 
 cat >>confdefs.h <<_ACEOF
-#define __CP_LOG_ENV "${withval}"
+#define __DARSHAN_LOG_ENV "${withval}"
 _ACEOF
 
-        __CP_LOG_ENV="${withval}"
+        __DARSHAN_LOG_ENV="${withval}"
         GOT_LOG_PATH=1
     fi
 
@@ -3611,10 +3611,10 @@ if test "${with_log_hints+set}" = set; then :
     else
 
 cat >>confdefs.h <<_ACEOF
-#define __CP_LOG_HINTS "${withval}"
+#define __DARSHAN_LOG_HINTS "${withval}"
 _ACEOF
 
-        __CP_LOG_HINTS="${withval}"
+        __DARSHAN_LOG_HINTS="${withval}"
         GOT_LOG_HINTS=1
     fi
 
@@ -3629,10 +3629,10 @@ if test "${with_log_path+set}" = set; then :
     else
 
 cat >>confdefs.h <<_ACEOF
-#define __CP_LOG_PATH "${withval}"
+#define __DARSHAN_LOG_PATH "${withval}"
 _ACEOF
 
-        __CP_LOG_PATH="${withval}"
+        __DARSHAN_LOG_PATH="${withval}"
         GOT_LOG_PATH=1
     fi
 
@@ -3647,10 +3647,10 @@ if test "${with_jobid_env+set}" = set; then :
     else
 
 cat >>confdefs.h <<_ACEOF
-#define CP_JOBID "${withval}"
+#define __DARSHAN_JOBID "${withval}"
 _ACEOF
 
-        CP_JOBID="${withval}"
+        __DARSHAN_JOBID="${withval}"
         GOT_JOBID=1
     fi
 
@@ -3666,11 +3666,11 @@ fi
 if test x$GOT_JOBID != x1; then
     as_fn_error $? "must provide --with-jobid-env=<name> argument to configure." "$LINENO" 5
 fi
-__CP_LOG_HINTS_DEFAULT="romio_no_indep_rw=true;cb_nodes=4"
+__DARSHAN_LOG_HINTS_DEFAULT="romio_no_indep_rw=true;cb_nodes=4"
 if test x$GOT_LOG_HINTS != x1; then
 
 cat >>confdefs.h <<_ACEOF
-#define __CP_LOG_HINTS "$__CP_LOG_HINTS_DEFAULT"
+#define __DARSHAN_LOG_HINTS "$__DARSHAN_LOG_HINTS_DEFAULT"
 _ACEOF
 
 fi
diff --git a/darshan-runtime/configure.in b/darshan-runtime/configure.in
index 210c5db..d88b8f7 100644
--- a/darshan-runtime/configure.in
+++ b/darshan-runtime/configure.in
@@ -46,7 +46,7 @@ fi]
 AC_ARG_ENABLE(group-readable-logs, 
 [  --enable-group-readable-logs Set log files to be group readable], 
 [if test "x$enableval" = "xyes" ; then
-    AC_DEFINE(__CP_GROUP_READABLE_LOGS, 1, Define if Darshan should set log files to be group readable)
+    AC_DEFINE(__DARSHAN_GROUP_READABLE_LOGS, 1, Define if Darshan should set log files to be group readable)
 fi]
 ,)
 
@@ -55,7 +55,7 @@ AC_ARG_WITH(mem-align,
     if test x$withval = xyes; then
         AC_MSG_ERROR(--with-mem-align must be given a number in bytes)
     else
-        AC_DEFINE_UNQUOTED(__CP_MEM_ALIGNMENT, ${withval}, Memory alignment in bytes)
+        AC_DEFINE_UNQUOTED(__DARSHAN_MEM_ALIGNMENT, ${withval}, Memory alignment in bytes)
         GOT_ALIGNMENT=1
     fi
 )
@@ -65,8 +65,8 @@ AC_ARG_WITH(log-path-by-env,
     if test x$withval = xyes; then
         AC_MSG_ERROR(--with-log-path-by-env must be given at least one variable name)
     else
-        AC_DEFINE_UNQUOTED(__CP_LOG_ENV, "${withval}", Comma separated list of env. variables to use for log path)
-        __CP_LOG_ENV="${withval}"
+        AC_DEFINE_UNQUOTED(__DARSHAN_LOG_ENV, "${withval}", Comma separated list of env. variables to use for log path)
+        __DARSHAN_LOG_ENV="${withval}"
         GOT_LOG_PATH=1
     fi
 )
@@ -76,8 +76,8 @@ AC_ARG_WITH(log-hints,
     if test x$withval = xyes; then
         AC_MSG_ERROR(--with-log-hints must be given an argument)
     else
-        AC_DEFINE_UNQUOTED(__CP_LOG_HINTS, "${withval}", Semicolon-separated list of MPI-IO hints for log file write)
-        __CP_LOG_HINTS="${withval}"
+        AC_DEFINE_UNQUOTED(__DARSHAN_LOG_HINTS, "${withval}", Semicolon-separated list of MPI-IO hints for log file write)
+        __DARSHAN_LOG_HINTS="${withval}"
         GOT_LOG_HINTS=1
     fi
 )
@@ -87,8 +87,8 @@ AC_ARG_WITH(log-path,
     if test x$withval = xyes; then
         AC_MSG_ERROR(--with-log-path must be given a pathname)
     else
-        AC_DEFINE_UNQUOTED(__CP_LOG_PATH, "${withval}", Location to store log files at run time)
-        __CP_LOG_PATH="${withval}"
+        AC_DEFINE_UNQUOTED(__DARSHAN_LOG_PATH, "${withval}", Location to store log files at run time)
+        __DARSHAN_LOG_PATH="${withval}"
         GOT_LOG_PATH=1
     fi
 )
@@ -100,8 +100,8 @@ AC_ARG_WITH(jobid-env,
     if test x$withval = xyes; then
         AC_MSG_ERROR(--with-jobid-env must be given a name)
     else
-        AC_DEFINE_UNQUOTED(CP_JOBID, "${withval}", Name of the environment variable that stores the jobid)
-        CP_JOBID="${withval}"
+        AC_DEFINE_UNQUOTED(__DARSHAN_JOBID, "${withval}", Name of the environment variable that stores the jobid)
+        __DARSHAN_JOBID="${withval}"
         GOT_JOBID=1
     fi
 )
@@ -115,10 +115,10 @@ fi
 if test x$GOT_JOBID != x1; then
     AC_MSG_ERROR(must provide --with-jobid-env=<name> argument to configure.)
 fi
-__CP_LOG_HINTS_DEFAULT="romio_no_indep_rw=true;cb_nodes=4"
+__DARSHAN_LOG_HINTS_DEFAULT="romio_no_indep_rw=true;cb_nodes=4"
 if test x$GOT_LOG_HINTS != x1; then
 dnl use default hints
-    AC_DEFINE_UNQUOTED(__CP_LOG_HINTS, "$__CP_LOG_HINTS_DEFAULT", Comma-separated list of MPI-IO hints for log file write)
+    AC_DEFINE_UNQUOTED(__DARSHAN_LOG_HINTS, "$__DARSHAN_LOG_HINTS_DEFAULT", Comma-separated list of MPI-IO hints for log file write)
 fi
 
 # checks to see how we can print 64 bit values on this architecture
@@ -313,7 +313,7 @@ DARSHAN_VERSION="AC_PACKAGE_VERSION"
 AC_SUBST(darshan_lib_path)
 AC_SUBST(darshan_share_path)
 AC_SUBST(LDFLAGS)
-AC_SUBST(__CP_LOG_PATH)
+AC_SUBST(__DARSHAN_LOG_PATH)
 AC_SUBST(DISABLE_LDPRELOAD)
 AC_SUBST(DARSHAN_VERSION)
 AC_SUBST(MPICH_LIB_OLD)
diff --git a/darshan-runtime/darshan-core.h b/darshan-runtime/darshan-core.h
index 7de647f..7437c4f 100644
--- a/darshan-runtime/darshan-core.h
+++ b/darshan-runtime/darshan-core.h
@@ -14,18 +14,17 @@
 #include "uthash.h"
 #include "darshan-log-format.h"
 
-/* TODO: drop CP_ and use DARSHAN_ */
-/* Environment variable to override CP_JOBID */
-#define CP_JOBID_OVERRIDE "DARSHAN_JOBID"
+/* Environment variable to override __DARSHAN_JOBID */
+#define DARSHAN_JOBID_OVERRIDE "DARSHAN_JOBID"
 
-/* Environment variable to override __CP_LOG_PATH */
-#define CP_LOG_PATH_OVERRIDE "DARSHAN_LOGPATH"
+/* Environment variable to override __DARSHAN_LOG_PATH */
+#define DARSHAN_LOG_PATH_OVERRIDE "DARSHAN_LOGPATH"
 
-/* Environment variable to override __CP_LOG_PATH */
-#define CP_LOG_HINTS_OVERRIDE "DARSHAN_LOGHINTS"
+/* Environment variable to override __DARSHAN_LOG_HINTS */
+#define DARSHAN_LOG_HINTS_OVERRIDE "DARSHAN_LOGHINTS"
 
-/* Environment variable to override __CP_MEM_ALIGNMENT */
-#define CP_MEM_ALIGNMENT_OVERRIDE "DARSHAN_MEMALIGN"
+/* Environment variable to override __DARSHAN_MEM_ALIGNMENT */
+#define DARSHAN_MEM_ALIGNMENT_OVERRIDE "DARSHAN_MEMALIGN"
 
 #define DARSHAN_CORE_MAX_RECORDS 1024
 
diff --git a/darshan-runtime/darshan-mk-log-dirs.pl.in b/darshan-runtime/darshan-mk-log-dirs.pl.in
index f102035..b94b3f1 100644
--- a/darshan-runtime/darshan-mk-log-dirs.pl.in
+++ b/darshan-runtime/darshan-mk-log-dirs.pl.in
@@ -10,7 +10,7 @@ use File::Basename;
 # LOGDIR/<year>/<month>/<day>/
 
 # use log dir specified at configure time
-$LOGDIR = "@__CP_LOG_PATH@";
+$LOGDIR = "@__DARSHAN_LOG_PATH@";
 
 
 my $year = (localtime)[5] + 1900;
diff --git a/darshan-runtime/darshan-runtime-config.h.in b/darshan-runtime/darshan-runtime-config.h.in
index 5ed35b4..ad3e9cc 100644
--- a/darshan-runtime/darshan-runtime-config.h.in
+++ b/darshan-runtime/darshan-runtime-config.h.in
@@ -3,9 +3,6 @@
 /* Define if building universal (internal helper macro) */
 #undef AC_APPLE_UNIVERSAL_BUILD
 
-/* Name of the environment variable that stores the jobid */
-#undef CP_JOBID
-
 /* Define if cuserid() should be disabled */
 #undef DARSHAN_DISABLE_CUSERID
 
@@ -91,19 +88,22 @@
 #endif
 
 /* Define if Darshan should set log files to be group readable */
-#undef __CP_GROUP_READABLE_LOGS
+#undef __DARSHAN_GROUP_READABLE_LOGS
+
+/* Name of the environment variable that stores the jobid */
+#undef __DARSHAN_JOBID
 
 /* Comma separated list of env. variables to use for log path */
-#undef __CP_LOG_ENV
+#undef __DARSHAN_LOG_ENV
 
 /* Comma-separated list of MPI-IO hints for log file write */
-#undef __CP_LOG_HINTS
+#undef __DARSHAN_LOG_HINTS
 
 /* Location to store log files at run time */
-#undef __CP_LOG_PATH
+#undef __DARSHAN_LOG_PATH
 
 /* Memory alignment in bytes */
-#undef __CP_MEM_ALIGNMENT
+#undef __DARSHAN_MEM_ALIGNMENT
 
 /* Generalized request type for MPI-IO */
 #undef __D_MPI_REQUEST
diff --git a/darshan-runtime/doc/darshan-runtime.txt b/darshan-runtime/doc/darshan-runtime.txt
index bd6b9b2..34849ad 100644
--- a/darshan-runtime/doc/darshan-runtime.txt
+++ b/darshan-runtime/doc/darshan-runtime.txt
@@ -477,7 +477,7 @@ behavior at runtime:
 * DARSHAN_DISABLE: disables Darshan instrumentation
 * DARSHAN_INTERNAL_TIMING: enables internal instrumentation that will print the time required to startup and shutdown Darshan to stderr at run time.
 * DARSHAN_LOGHINTS: specifies the MPI-IO hints to use when storing the Darshan output file.  The format is a semicolon-delimited list of key=value pairs, for example: hint1=value1;hint2=value2
-* DARSHAN_MEMALIGN: specifies a value for memory alignment (CP_MEM_ALIGNMENT)
+* DARSHAN_MEMALIGN: specifies a value for system memory alignment
 * DARSHAN_JOBID: specifies the name of the environment variable to use for the job identifier, such as PBS_JOBID
 * DARSHAN_DISABLE_SHARED_REDUCTION: disables the step in Darshan aggregation
 in which files that were accessed by all ranks are collapsed into a single
diff --git a/maint/config/check_zlib.m4 b/maint/config/check_zlib.m4
index ba74736..1979f95 100644
--- a/maint/config/check_zlib.m4
+++ b/maint/config/check_zlib.m4
@@ -11,8 +11,8 @@ AC_ARG_WITH(zlib,
     ZLIB_HOME="$withval"
     LDFLAGS="$LDFLAGS -L${ZLIB_HOME}/lib"
     CPPFLAGS="$CPPFLAGS -I${ZLIB_HOME}/include"
-    __CP_ZLIB_LINK_FLAGS="-L${ZLIB_HOME}/lib"
-    __CP_ZLIB_INCLUDE_FLAGS="-I${ZLIB_HOME}/include"
+    __DARSHAN_ZLIB_LINK_FLAGS="-L${ZLIB_HOME}/lib"
+    __DARSHAN_ZLIB_INCLUDE_FLAGS="-I${ZLIB_HOME}/include"
   else
     AC_MSG_WARN([Sorry, $withval does not exist, checking usual places])
   fi


hooks/post-receive
diff --git a/darshan-runtime/lib/darshan-core.c b/darshan-runtime/lib/darshan-core.c
index b534a1f..17e6b77 100644
--- a/darshan-runtime/lib/darshan-core.c
+++ b/darshan-runtime/lib/darshan-core.c
@@ -140,10 +140,10 @@ void darshan_core_initialize(int argc, char **argv)
     /* setup darshan runtime if darshan is enabled and hasn't been initialized already */
     if(!getenv("DARSHAN_DISABLE") && !darshan_core)
     {
-        #if (__CP_MEM_ALIGNMENT < 1)
+        #if (__DARSHAN_MEM_ALIGNMENT < 1)
             #error Darshan must be configured with a positive value for --with-mem-align
         #endif
-        envstr = getenv("DARSHAN_MEMALIGN");
+        envstr = getenv(DARSHAN_MEM_ALIGNMENT_OVERRIDE);
         if(envstr)
         {
             ret = sscanf(envstr, "%d", &tmpval);
@@ -155,7 +155,7 @@ void darshan_core_initialize(int argc, char **argv)
         }
         else
         {
-            darshan_mem_alignment = __CP_MEM_ALIGNMENT;
+            darshan_mem_alignment = __DARSHAN_MEM_ALIGNMENT;
         }
 
         /* avoid floating point errors on faulty input */
@@ -303,11 +303,11 @@ void darshan_core_shutdown()
     /* set darshan job id/metadata and constuct log file name on rank 0 */
     if(my_rank == 0)
     {
-        /* Use CP_JOBID_OVERRIDE for the env var or CP_JOBID */
-        envjobid = getenv(CP_JOBID_OVERRIDE);
+        /* Use DARSHAN_JOBID_OVERRIDE for the env var or __DARSHAN_JOBID */
+        envjobid = getenv(DARSHAN_JOBID_OVERRIDE);
         if(!envjobid)
         {
-            envjobid = CP_JOBID;
+            envjobid = __DARSHAN_JOBID;
         }
 
         /* find a job id */
@@ -590,7 +590,7 @@ void darshan_core_shutdown()
     {
         if(getenv("DARSHAN_LOGFILE"))
         {
-#ifdef __CP_GROUP_READABLE_LOGS
+#ifdef __DARSHAN_GROUP_READABLE_LOGS
             chmod(logfile_name, (S_IRUSR|S_IRGRP));
 #else
             chmod(logfile_name, (S_IRUSR));
@@ -612,7 +612,7 @@ void darshan_core_shutdown()
                 sprintf(tmp_index, "_%d.darshan", (int)(end_log_time-start_log_time+1));
                 rename(logfile_name, new_logfile_name);
                 /* set permissions on log file */
-#ifdef __CP_GROUP_READABLE_LOGS
+#ifdef __DARSHAN_GROUP_READABLE_LOGS
                 chmod(new_logfile_name, (S_IRUSR|S_IRGRP));
 #else
                 chmod(new_logfile_name, (S_IRUSR));
@@ -688,7 +688,7 @@ static void darshan_get_logfile_name(char* logfile_name, int jobid, struct tm* s
     char* logpath;
     char* logname_string;
     char* logpath_override = NULL;
-#ifdef __CP_LOG_ENV
+#ifdef __DARSHAN_LOG_ENV
     char env_check[256];
     char* env_tok;
 #endif
@@ -716,12 +716,12 @@ static void darshan_get_logfile_name(char* logfile_name, int jobid, struct tm* s
     {
         /* otherwise, generate the log path automatically */
 
-        /* Use CP_LOG_PATH_OVERRIDE for the value or __CP_LOG_PATH */
-        logpath = getenv(CP_LOG_PATH_OVERRIDE);
+        /* Use DARSHAN_LOG_PATH_OVERRIDE for the value or __DARSHAN_LOG_PATH */
+        logpath = getenv(DARSHAN_LOG_PATH_OVERRIDE);
         if(!logpath)
         {
-#ifdef __CP_LOG_PATH
-            logpath = __CP_LOG_PATH;
+#ifdef __DARSHAN_LOG_PATH
+            logpath = __DARSHAN_LOG_PATH;
 #endif
         }
 
@@ -766,12 +766,12 @@ static void darshan_get_logfile_name(char* logfile_name, int jobid, struct tm* s
          * argument, which allows the user to specify an absolute path to
          * place logs via an env variable.
          */
-#ifdef __CP_LOG_ENV
+#ifdef __DARSHAN_LOG_ENV
         /* just silently skip if the environment variable list is too big */
-        if(strlen(__CP_LOG_ENV) < 256)
+        if(strlen(__DARSHAN_LOG_ENV) < 256)
         {
             /* copy env variable list to a temporary buffer */
-            strcpy(env_check, __CP_LOG_ENV);
+            strcpy(env_check, __DARSHAN_LOG_ENV);
             /* tokenize the comma-separated list */
             env_tok = strtok(env_check, ",");
             if(env_tok)
@@ -847,10 +847,10 @@ static void darshan_log_record_hints_and_ver(struct darshan_core_runtime* core)
     /* check environment variable to see if the default MPI file hints have
      * been overridden
      */
-    hints = getenv(CP_LOG_HINTS_OVERRIDE);
+    hints = getenv(DARSHAN_LOG_HINTS_OVERRIDE);
     if(!hints)
     {
-        hints = __CP_LOG_HINTS;
+        hints = __DARSHAN_LOG_HINTS;
     }
 
     if(!hints || strlen(hints) < 1)
@@ -1153,10 +1153,10 @@ static int darshan_log_open_all(char *logfile_name, MPI_File *log_fh)
      */
     MPI_Info_create(&info);
 
-    hints = getenv(CP_LOG_HINTS_OVERRIDE);
+    hints = getenv(DARSHAN_LOG_HINTS_OVERRIDE);
     if(!hints)
     {
-        hints = __CP_LOG_HINTS;
+        hints = __DARSHAN_LOG_HINTS;
     }
 
     if(hints && strlen(hints) > 0)
--



More information about the Darshan-commits mailing list